==> scanbot_sdk-2.4.1.tar.gz: ios/Classes/Presenters/MRZScannerPresenter.swift <==
//
//  MRZScannerPresenter.swift
//  scanbot_sdk
//
//  Created by Zhenya Knizhnik on 26.08.19.
//

import UIKit
import ScanbotSDK
import Flutter

class MRZScannerPresenter: NSObject {
    private var resultHandler: FlutterResult?
    private weak var presenter: UIViewController?

    func present(on presenter: UIViewController,
                 with configuration: SBSDKUIMachineCodeScannerConfiguration,
                 result: @escaping FlutterResult) {
        self.resultHandler = result
        self.presenter = presenter
        let controller = SBSDKUIMRZScannerViewController.createNew(with: configuration, andDelegate: self)
        controller.modalPresentationStyle = .fullScreen
        presenter.present(controller, animated: true, completion: nil)
    }
}

extension MRZScannerPresenter: SBSDKUIMRZScannerViewControllerDelegate {
    func mrzDetectionViewController(_ viewController: SBSDKUIMRZScannerViewController,
                                    didDetect zone: SBSDKMachineReadableZoneRecognizerResult) {
        viewController.isRecognitionEnabled = false
        self.presenter?.dismiss(animated: true, completion: { [weak self] in
            self?.resultHandler?(zone.encodedString)
            self?.resultHandler = nil
            self?.presenter = nil
        })
    }
    
    func mrzDetectionViewControllerDidCancel(_ viewController: SBSDKUIMRZScannerViewController) {
        self.resultHandler?("CANCELED")
        self.resultHandler = nil
        self.presenter = nil
    }
}

==> scanbot_sdk-2.9.0.tar.gz: ios/Classes/Presenters/MRZScannerPresenter.swift <==
//
//  MRZScannerPresenter.swift
//  scanbot_sdk
//
//  Created by Zhenya Knizhnik on 26.08.19.
//

import UIKit
import ScanbotSDK
import Flutter

class MRZScannerPresenter: NSObject {
    private var resultHandler: FlutterResult?
    private weak var presenter: UIViewController?

    func present(on presenter: UIViewController,
                 with configuration: SBSDKUIMRZScannerConfiguration,
                 result: @escaping FlutterResult) {
        self.resultHandler = result
        self.presenter = presenter
        let controller = SBSDKUIMRZScannerViewController.createNew(with: configuration, andDelegate: self)
        controller.modalPresentationStyle = .fullScreen
        presenter.present(controller, animated: true, completion: nil)
    }
}

extension MRZScannerPresenter: SBSDKUIMRZScannerViewControllerDelegate {
    func mrzDetectionViewController(_ viewController: SBSDKUIMRZScannerViewController,
                                    didDetect zone: SBSDKMachineReadableZoneRecognizerResult) {
        viewController.isRecognitionEnabled = false
        self.presenter?.dismiss(animated: true, completion: { [weak self] in
            self?.resultHandler?(zone.encodedString)
            self?.resultHandler = nil
            self?.presenter = nil
        })
    }
    
    func mrzDetectionViewControllerDidCancel(_ viewController: SBSDKUIMRZScannerViewController) {
        self.resultHandler?("CANCELED")
        self.resultHandler = nil
        self.presenter = nil
    }
}
